/**********************************************************************
  Initialize ppcsim system
  $Id: init_system.c,v 1.7 2003/01/07 16:44:11 tane Exp $
**********************************************************************/
#include "common.h"
#include "ppcsim.h"
#include "processor.h"
#include "funcs.h"
#include "memory.h"
#include "op_exec.h"
#include "op_scemu.h"

int set_initparams()
{
  default_textsize         = DEFAULT_TEXTSIZE ;
  default_linux_textsize   = DEFAULT_LINUX_TEXTSIZE ;
  default_heaptop          = DEFAULT_HEAPTOP ;
  default_heapsize         = DEFAULT_HEAPSIZE ;
  default_brktop           = DEFAULT_BRKTOP ;
  default_brksize          = DEFAULT_BRKSIZE ;
  default_exec_start       = DEFAULT_EXEC_START ;
  default_stack_top_offset = DEFAULT_STACK_TOP_OFFSET ;
  sc_emu_mode              = NEWLIBPOWERX ;

  return(NORMAL_EXIT) ;
}  

int init_system()
{
  int i,j ;
  int res ; 
  
  if( simlog==NULL ){
    simmsgfp=DEFAULT_SIMMSG_OUT ;
  }else{
    simmsgfp=fopen( simlog,"wb" ) ;
    if( simmsgfp==NULL ){
      SYSERR("Can not open simulation log file(%s)\n",simlog ) ;
      exit(0) ;
    }
  }

  init_sighandl_ppcsim() ;
  init_excp() ;
  init_op_func_tbl() ;
  
  proc_list.cur_id=-1 ;
  for( i=0 ; i<MAX_PROCESS_ID ; i++ ){
    for( j=0 ; j<MEM_SEGMENT_NUM ; j++ ){
      proc_list.proc[i].mem[j]=NULL ;
      proc_list.proc[i].mem_size[j]=0 ;
      proc_list.proc[i].mem_attr[j]=MEM_ATTR_NORMAL ;
    }
    for( j=0 ; j<MAX_OPEN_FD ; j++ ){
      proc_list.proc[i].openfd[j]=-1 ;
    }
  }
  res=create_proc( &proc_list, DEFAULT_INIT_MEMSIZE ) ; /*** pid=0 𐶐 ***/
  if( res!=NORMAL_EXIT ){
    SYSERR("Out of memory\n") ;
    exit(0) ;
  }

  init_sim_io( &proc_list.proc[0] ) ;
  
  trace.size=DEFAULT_TRACE_SIZE ;
  trace.ptr =0 ;
  trace.buf =malloc( trace.size*sizeof(struct TRACE_BUF_STRUCT) ) ;
  if( trace.buf==NULL ){
    SYSERR("Out of memory\n") ;
    exit(0) ;
  }
  for( i=0 ; i<trace.size ; i++ ){
    trace.buf[i].pc  =0xffffffff ;
    trace.buf[i].inst=0x00000000 ;
  }
#ifdef SUPPORT_SYSTEMCALL_EMULATION
  for( i=0 ; i<DIR_ENTRY_MAX ; i++ ){
    dir_list[i].ppc_mem_ptr=0 ;
    dir_list[i].cygwin_DIR =NULL ;
  }
#endif
  iexe_count =  0 ;
  ppmsg_stat.msg_type  =PP_DUMP_PC ;
  ppmsg_stat.print_type=PRINT_NON  ;
  truss_stat =OFF ;
  trace_stat.msg_type  =TRACE_OFF ;
  trace_stat.print_type=PRINT_NON ;
  verbose    =OFF ;
  for( i=0 ; i<MAX_PROCESS_ID ; i++ ){
    proc_list.proc[i].bp_num    = 0 ;
    proc_list.proc[i].bp_id     = 0 ;
    proc_list.proc[i].pp_num    = 0 ;
    proc_list.proc[i].pp_id     = 0 ;
  }
  
  return(NORMAL_EXIT) ;
}  
